# Installation

You should install this package into a virtual environment.  You can use
[uv](https://docs.astral.sh/uv/){:target = "_blank"} (recommended), or
[Poetry](https://python-poetry.org/){:target = "_blank"} to do this:

```console
$ uv add simple-toml-settings
```

or

```console
$ poetry add simple-toml-settings
```

If you don't want to use Poetry, you can use pip from inside your virtual
environment:

```console
$ pip install simple-toml-settings
```
